==> mobile_pos-1.1.1.tar.gz: lib/src/views/terminal/widget/filter_transaction_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/shared_widgets/expansion_tile.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

enum FilterType { duration, direction }

class FilterTransactionSheet extends StatefulWidget {
  const FilterTransactionSheet({super.key});

  @override
  State<FilterTransactionSheet> createState() => _FilterTransactionSheetState();
}

class _FilterTransactionSheetState extends State<FilterTransactionSheet> {
  Map<FilterType, String> selectedOptions = {};

  final TextEditingController phoneController = TextEditingController();
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(16),
          Row(
            children: [
              Expanded(
                  child: Text("Filter Transactions",
                      style: headling1.copyWith(
                          color: pluginConfig.theme!.primaryColor,
                          fontWeight: FontWeight.w700,
                          fontSize: 20))),
              GestureDetector(
                onTap: () => Navigator.pop(context),
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              )
            ],
          ),
          const Gap(16),
          SingleChildScrollView(
            scrollDirection: Axis.horizontal,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                for (var entry in selectedOptions.entries) ...[
                  previewItem(entry.key, entry.value)
                ]
              ],
            ),
          ),
          const Gap(24),
          BankBoxExpansionTile(
            title: "Duration",
            animatedChild: Align(
              alignment: Alignment.topLeft,
              child: Wrap(
                children: [
                  DurationItem(
                    value: 7,
                    onSelected: (type, name, {int? value}) {
                      selectedOptions.addAll({type: name});
                      setState(() {});
                    },
                    name: "Recent",
                    filterType: FilterType.duration,
                    selecteItem: selectedOptions[FilterType.duration] ?? "",
                  ),
                  DurationItem(
                    onSelected: (type, name, {int? value}) {
                      selectedOptions.addAll({type: name});
                      setState(() {});
                    },
                    value: 14,
                    name: "14 Days",
                    filterType: FilterType.duration,
                    selecteItem: selectedOptions[FilterType.duration] ?? "",
                  ),
                  DurationItem(
                    value: 30,
                    onSelected: (type, name, {int? value}) {
                      selectedOptions.addAll({type: name});
                      setState(() {});
                    },
                    name: "30 Days",
                    filterType: FilterType.duration,
                    selecteItem: selectedOptions[FilterType.duration] ?? "",
                  ),
                  DurationItem(
                    value: 30,
                    onSelected: (type, name, {int? value}) {
                      selectedOptions.addAll({type: name});
                      setState(() {});
                    },
                    name: "Custom",
                    filterType: FilterType.duration,
                    selecteItem: selectedOptions[FilterType.duration] ?? "",
                  )
                ],
              ),
            ),
          ),
          const Gap(12),
          BankBoxExpansionTile(
              title: "Direction",
              animatedChild: Align(
                  alignment: Alignment.topLeft,
                  child: Wrap(
                    children: [
                      DurationItem(
                        onSelected: (type, name, {int? value}) {
                          selectedOptions.addAll({type: name});
                          setState(() {});
                        },
                        name: "Credit",
                        filterType: FilterType.direction,
                        selecteItem:
                            selectedOptions[FilterType.direction] ?? "",
                      ),
                      DurationItem(
                        onSelected: (type, name, {int? value}) {
                          selectedOptions.addAll({type: name});
                          setState(() {});
                        },
                        name: "Failed",
                        filterType: FilterType.direction,
                        selecteItem:
                            selectedOptions[FilterType.direction] ?? "",
                      ),
                    ],
                  ))),
          const Gap(24),
          RavenPayButton(
            enabled: selectedOptions.isNotEmpty,
            onPressed: () {
              Navigator.pop(context, selectedOptions);
            },
            buttonText: "Apply",
          ),
          const Gap(24),
        ],
      ),
    );
  }

  Widget previewItem(FilterType key, String name) {
    return Container(
      margin: const EdgeInsets.only(right: 12),
      child: Chip(
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(24)),
        padding: const EdgeInsets.symmetric(vertical: 8, horizontal: 6),
        backgroundColor: pluginTheme.isLightTheme
            ? AppColors.lightGrey3
            : pluginTheme.getFGColor,
        labelStyle:
            subtitle.copyWith(fontSize: 16, fontWeight: FontWeight.w600),
        deleteIconColor: AppColors.ravenRed,
        label: Text(name),
        onDeleted: () {
          selectedOptions.remove(key);
          setState(() {});
        },
      ),
    );
  }
}

class DurationItem extends StatelessWidget {
  final FilterType filterType;
  final Function(FilterType, String, {int? value}) onSelected;
  final String name;

  final int? value;
  final String selecteItem;
  const DurationItem(
      {super.key,
      required this.filterType,
      required this.onSelected,
      required this.name,
      this.value,
      required this.selecteItem});

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        onSelected(filterType, name, value: value);
      },
      child: Container(
          margin: const EdgeInsets.only(right: 8, top: 12),
          decoration: BoxDecoration(
              color: selecteItem == name
                  ? pluginConfig.theme!.primaryColor.withOpacity(0.07)
                  : (pluginTheme.isLightTheme
                      ? AppColors.ravenLightGrey4
                      : AppColors.ravenLightGrey4.withOpacity(0.1)),
              borderRadius: BorderRadius.circular(16)),
          padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 6),
          child: Text(
            name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w400,
                color: selecteItem == name
                    ? pluginConfig.theme!.primaryColor
                    : (pluginTheme.isLightTheme ? Colors.black : Colors.white)),
          )),
    );
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/views/terminal/widget/filter_transaction_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/shared_widgets/expansion_tile.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_terminal_details.dart';

enum FilterType { duration, direction }

class FilterTransactionSheet extends StatefulWidget {
  const FilterTransactionSheet({super.key});

  @override
  State<FilterTransactionSheet> createState() => _FilterTransactionSheetState();
}

class _FilterTransactionSheetState extends State<FilterTransactionSheet> {
  Map<FilterType, String> selectedOptions = {};

  final TextEditingController phoneController = TextEditingController();
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(16),
          const RavenPayBottomSheetCapsule(),
          const Gap(16),
          Row(
            children: [
              Expanded(
                  child: Text("Filter Transactions",
                      style: headling1.copyWith(
                          color: pluginConfig.theme!.primaryColor,
                          fontWeight: FontWeight.w700,
                          fontSize: 20))),
              GestureDetector(
                onTap: () => Navigator.pop(context),
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              )
            ],
          ),
          const Gap(16),
          SingleChildScrollView(
            scrollDirection: Axis.horizontal,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                for (var entry in selectedOptions.entries) ...[
                  previewItem(entry.key, entry.value)
                ]
              ],
            ),
          ),
          const Gap(24),
          BankBoxExpansionTile(
            title: "Duration",
            animatedChild: Align(
              alignment: Alignment.topLeft,
              child: Wrap(
                children: [
                  DurationItem(
                    value: 7,
                    onSelected: (type, name, {int? value}) {
                      selectedOptions.addAll({type: name});
                      setState(() {});
                    },
                    name: "Recent",
                    filterType: FilterType.duration,
                    selecteItem: selectedOptions[FilterType.duration] ?? "",
                  ),
                  DurationItem(
                    onSelected: (type, name, {int? value}) {
                      selectedOptions.addAll({type: name});
                      setState(() {});
                    },
                    value: 14,
                    name: "14 Days",
                    filterType: FilterType.duration,
                    selecteItem: selectedOptions[FilterType.duration] ?? "",
                  ),
                  DurationItem(
                    value: 30,
                    onSelected: (type, name, {int? value}) {
                      selectedOptions.addAll({type: name});
                      setState(() {});
                    },
                    name: "30 Days",
                    filterType: FilterType.duration,
                    selecteItem: selectedOptions[FilterType.duration] ?? "",
                  ),
                  DurationItem(
                    value: 30,
                    onSelected: (type, name, {int? value}) {
                      selectedOptions.addAll({type: name});
                      setState(() {});
                    },
                    name: "Custom",
                    filterType: FilterType.duration,
                    selecteItem: selectedOptions[FilterType.duration] ?? "",
                  )
                ],
              ),
            ),
          ),
          const Gap(12),
          BankBoxExpansionTile(
              title: "Direction",
              animatedChild: Align(
                  alignment: Alignment.topLeft,
                  child: Wrap(
                    children: [
                      DurationItem(
                        onSelected: (type, name, {int? value}) {
                          selectedOptions.addAll({type: name});
                          setState(() {});
                        },
                        name: "Credit",
                        filterType: FilterType.direction,
                        selecteItem:
                            selectedOptions[FilterType.direction] ?? "",
                      ),
                      DurationItem(
                        onSelected: (type, name, {int? value}) {
                          selectedOptions.addAll({type: name});
                          setState(() {});
                        },
                        name: "Failed",
                        filterType: FilterType.direction,
                        selecteItem:
                            selectedOptions[FilterType.direction] ?? "",
                      ),
                    ],
                  ))),
          const Gap(24),
          RavenPayButton(
            enabled: selectedOptions.isNotEmpty,
            onPressed: () {
              Navigator.pop(context, selectedOptions);
            },
            buttonText: "Apply",
          ),
          const Gap(24),
        ],
      ),
    );
  }

  Widget previewItem(FilterType key, String name) {
    return Container(
      margin: const EdgeInsets.only(right: 12),
      child: Chip(
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(24)),
        padding: const EdgeInsets.symmetric(vertical: 8, horizontal: 6),
        backgroundColor: pluginTheme.isLightTheme
            ? AppColors.lightGrey3
            : pluginTheme.getFGColor,
        labelStyle:
            subtitle.copyWith(fontSize: 16, fontWeight: FontWeight.w600),
        deleteIconColor: AppColors.ravenRed,
        label: Text(name),
        onDeleted: () {
          selectedOptions.remove(key);
          setState(() {});
        },
      ),
    );
  }
}

class DurationItem extends StatelessWidget {
  final FilterType filterType;
  final Function(FilterType, String, {int? value}) onSelected;
  final String name;

  final int? value;
  final String selecteItem;
  const DurationItem(
      {super.key,
      required this.filterType,
      required this.onSelected,
      required this.name,
      this.value,
      required this.selecteItem});

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        onSelected(filterType, name, value: value);
      },
      child: Container(
          margin: const EdgeInsets.only(right: 8, top: 12),
          decoration: BoxDecoration(
              color: selecteItem == name
                  ? pluginConfig.theme!.primaryColor.withOpacity(0.07)
                  : (pluginTheme.isLightTheme
                      ? AppColors.ravenLightGrey4
                      : AppColors.ravenLightGrey4.withOpacity(0.1)),
              borderRadius: BorderRadius.circular(16)),
          padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 6),
          child: Text(
            name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w400,
                color: selecteItem == name
                    ? pluginConfig.theme!.primaryColor
                    : (pluginTheme.isLightTheme ? Colors.black : Colors.white)),
          )),
    );
  }
}
